==> nomachine-8.11.3-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXTwoFactorManager.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXTwoFactorManager::printSavedUserList{package NXTwoFactorManager;no 
warnings;NXMsg::send_response (
"\x69\x43\x4d\x44\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x55\x73\x65\x72\x73\x4b\x65\x79\x73\x4c\x69\x73\x74"
,"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4d\x61\x6e\x61\x67\x65\x72");
main::nxrequire (
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x44\x42");(my (
@publicKeys)=NXTwoFactorLoginDB::getAllPublicKeys ());(my (@labels)=(
"\x55\x73\x65\x72","\x4b\x65\x79"));(my (%keys)=());for ((my $i=
(0x1032+ 3988-0x1fc6));($i<@publicKeys);($i=($i+(0x0304+ 266-0x040c)))){(my (
%key)=());($key{"\x55\x73\x65\x72"}=$publicKeys[$i]);($key{"\x4b\x65\x79"}=
$publicKeys[$i+(0x19af+ 571-0x1be9)]);($keys{$i}=(\%key));}return (
NXTools::printTable ((\@labels),(\%keys)));}sub 
NXTwoFactorManager::removeUserKeys{package NXTwoFactorManager;no warnings;(my $user
=shift (@_));main::nxrequire (
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x44\x42");(my (
@keys)=NXTwoFactorLoginDB::getAllPublicKeys ($user));if ((scalar (@keys)==
(0x042a+ 4226-0x14ac))){NXMsg::error (
"\x69\x43\x4d\x44\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x55\x73\x65\x72\x4b\x65\x79\x73\x4e\x6f\x74\x45\x78\x69\x73\x74\x73"
,"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4d\x61\x6e\x61\x67\x65\x72",
$user);return;}if ((NXTwoFactorLoginDB::removeUserKeys ($user)>
(0x0211+ 893-0x058e))){NXMsg::send_response (
"\x69\x43\x4d\x44\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x55\x73\x65\x72\x4b\x65\x79\x73\x52\x65\x6d\x6f\x76\x65\x64"
,"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4d\x61\x6e\x61\x67\x65\x72",
$user);return;}NXMsg::error (
"\x69\x43\x4d\x44\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x55\x73\x65\x72\x4b\x65\x79\x73\x52\x65\x6d\x6f\x76\x65\x45\x72\x72\x6f\x72"
,"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4d\x61\x6e\x61\x67\x65\x72",
$user);}package NXTwoFactorManager;no warnings;NXMsg::register_response (
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4d\x61\x6e\x61\x67\x65\x72",
"\x69\x43\x4d\x44\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x55\x73\x65\x72\x73\x4b\x65\x79\x73\x4c\x69\x73\x74"
,$GLOBAL::MSG_2FA_SAVED_KEYS_LIST);NXMsg::register_response (
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4d\x61\x6e\x61\x67\x65\x72",
"\x69\x43\x4d\x44\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x55\x73\x65\x72\x4b\x65\x79\x73\x52\x65\x6d\x6f\x76\x65\x64"
,$GLOBAL::MSG_2FA_SAVED_KEYS_DEL);NXMsg::register_error (
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4d\x61\x6e\x61\x67\x65\x72",
"\x69\x43\x4d\x44\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x55\x73\x65\x72\x4b\x65\x79\x73\x4e\x6f\x74\x45\x78\x69\x73\x74\x73"
,(0x1a63+ 1456-0x1e1f));NXMsg::register_error (
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4d\x61\x6e\x61\x67\x65\x72",
"\x69\x43\x4d\x44\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x55\x73\x65\x72\x4b\x65\x79\x73\x52\x65\x6d\x6f\x76\x65\x45\x72\x72\x6f\x72"
,(0x1aff+ 2242-0x21cd));return ((0x0396+ 906-0x071f));

==> nomachine-8.12.12-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXTwoFactorManager.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXTwoFactorManager::printSavedUserList{package NXTwoFactorManager;no 
warnings;NXMsg::send_response (
"\x69\x43\x4d\x44\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x55\x73\x65\x72\x73\x4b\x65\x79\x73\x4c\x69\x73\x74"
,"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4d\x61\x6e\x61\x67\x65\x72");
main::nxrequire (
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x44\x42");(my (
@publicKeys)=NXTwoFactorLoginDB::getAllPublicKeys ());(my (@labels)=(
"\x55\x73\x65\x72","\x4b\x65\x79"));(my (%keys)=());for ((my $i=
(0x05b2+ 2508-0x0f7e));($i<@publicKeys);($i=($i+(0x0cb2+ 4703-0x1f0f)))){(my (
%key)=());($key{"\x55\x73\x65\x72"}=$publicKeys[$i]);($key{"\x4b\x65\x79"}=
$publicKeys[$i+(0x0ab0+ 503-0x0ca6)]);($keys{$i}=(\%key));}return (
NXTools::printTable ((\@labels),(\%keys)));}sub 
NXTwoFactorManager::removeUserKeys{package NXTwoFactorManager;no warnings;(my $user
=shift (@_));main::nxrequire (
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4c\x6f\x67\x69\x6e\x44\x42");(my (
@keys)=NXTwoFactorLoginDB::getAllPublicKeys ($user));if ((scalar (@keys)==
(0x02ba+ 5774-0x1948))){NXMsg::error (
"\x69\x43\x4d\x44\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x55\x73\x65\x72\x4b\x65\x79\x73\x4e\x6f\x74\x45\x78\x69\x73\x74\x73"
,"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4d\x61\x6e\x61\x67\x65\x72",
$user);return;}if ((NXTwoFactorLoginDB::removeUserKeys ($user)>
(0x043a+ 3778-0x12fc))){NXMsg::send_response (
"\x69\x43\x4d\x44\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x55\x73\x65\x72\x4b\x65\x79\x73\x52\x65\x6d\x6f\x76\x65\x64"
,"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4d\x61\x6e\x61\x67\x65\x72",
$user);return;}NXMsg::error (
"\x69\x43\x4d\x44\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x55\x73\x65\x72\x4b\x65\x79\x73\x52\x65\x6d\x6f\x76\x65\x45\x72\x72\x6f\x72"
,"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4d\x61\x6e\x61\x67\x65\x72",
$user);}package NXTwoFactorManager;no warnings;NXMsg::register_response (
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4d\x61\x6e\x61\x67\x65\x72",
"\x69\x43\x4d\x44\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x55\x73\x65\x72\x73\x4b\x65\x79\x73\x4c\x69\x73\x74"
,$GLOBAL::MSG_2FA_SAVED_KEYS_LIST);NXMsg::register_response (
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4d\x61\x6e\x61\x67\x65\x72",
"\x69\x43\x4d\x44\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x55\x73\x65\x72\x4b\x65\x79\x73\x52\x65\x6d\x6f\x76\x65\x64"
,$GLOBAL::MSG_2FA_SAVED_KEYS_DEL);NXMsg::register_error (
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4d\x61\x6e\x61\x67\x65\x72",
"\x69\x43\x4d\x44\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x55\x73\x65\x72\x4b\x65\x79\x73\x4e\x6f\x74\x45\x78\x69\x73\x74\x73"
,(0x0b81+ 7376-0x265d));NXMsg::register_error (
"\x4e\x58\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x4d\x61\x6e\x61\x67\x65\x72",
"\x69\x43\x4d\x44\x54\x77\x6f\x46\x61\x63\x74\x6f\x72\x55\x73\x65\x72\x4b\x65\x79\x73\x52\x65\x6d\x6f\x76\x65\x45\x72\x72\x6f\x72"
,(0x0eb0+ 1432-0x1254));return ((0x123b+ 4515-0x23dd));
